/*********************************************************************
 *  SPDX-License-Identifier: MIT									 *
 *  Copyright (C) 2019-2020 by Helge Kortendieck  alan@kasmithee.de  *
 *                                                                   *
 *  This file is part of qublc.                                      *
 *********************************************************************/

#include "abouthelp.h"

aboutHelp::aboutHelp(QDialog* parent)
	: QDialog(parent)
{
	uih.setupUi(&wHelp);
	connect(uih.pB_Close, SIGNAL(clicked()), this, SLOT(dlgClose()));
}

aboutHelp::~aboutHelp()
{
}

void aboutHelp::dlgShow(int iD)				// show dialog: 1=about, 2=Help, 3=no system tray
{
//cout << "dlgShow reached : " << endl;
	iDlg = iD;
	if (wHelp.isVisible() == true) {
		wHelp.hide();
	}
	textSet();
	if (iDlg == 1) {
		uih.tb_Help->setHtml(sHelp);
		wHelp.setWindowTitle(tr("about qublc"));
		wHelp.resize(600, 300);
	} else if (iDlg == 2) {
		uih.tb_Help->setHtml(sHelp);
		wHelp.setWindowTitle(tr("qublc - help"));
		wHelp.showFullScreen();
	}
	if (iDlg == 1) {							// 1=about
		qPos = QCursor::pos();
		iD = qPos.x() - 450;
		if(iD < 0) {
			iD = 0;
		}
		iD2 = qPos.y() - 175;
		if (iD2 < 0) {
			iD2 = 0;
		}
		wHelp.move(iD, iD2);
	}
	wHelp.show();
}

void aboutHelp::dlgClose()
{
	wHelp.hide();
	emit sigDelAhw();
}

void aboutHelp::textSet()
{
	if (iDlg == 1) {
		sHelp = tr("<html><body>"
		          "qublc - Qt(5) based Unbound Block List Creator<br>"
		          "Manage sites to be blocked by unbound and create a conf file for unbound from it.<p>"
		          "Version 0.9.5, Copyright 2019-2020 by Helge Kortendieck, alan@kasmithee.de .<p>"
		          "This program is released under the MIT license, except of it's icons.<br>"
		          "See the online help for the icon licenses.<br>"
                  "</body></html>");
	} else if (iDlg == 2) {
		sHelp = tr("<html><body>"
		           "<a name=""Top""><b>Table of content</b></a><br>"
		           "<a href=""#Intro"">Introduction</a><br>"
		           "<a href=""#Usage"">How to use</a><br>"
		           "<a href=""#About cookies vs tracking cookies"">Cookies</a><br>"
		           "<a href=""#Credits"">Credits</a><p>"

		           "<hr>"
		           "<a name=""Intro""><b><u>Introduction</u></b></a><p>"
		           "qublc - Qt(5) based Unbound Block List Creator is a simple, Qt5 based GUI program to manage sites, which should be blocked by unbound.<p>"
		           "About unbound, Feb. 2020, https://nlnetlabs.nl/projects/unbound/about/, 'Unbound is a validating, recursive, caching DNS resolver.'<p>"
		           "unbound is a program that usually runs on a router/firewall and resolves DNS entries. Means, translating URL names into IP4 or IP6 adress entries.<br>"
		           "You type e. g. foo.com and unbound will translate this to xxx.yyy.zzz.aaa , IP4 adress name, under which foo.com can actually be reached.<p>"
		           "In more detail, unbound first looks into an internal list and if the URL/adress combination is not found, it will ask your provider's nameservers or any other nameserver you specified in your router to resolve the URL name to the IP4 or IP6 adress.<br>"
		           "It will also add this URL/adress combination to it's internal list for future usage.<br>"
		           "One can also specify a list with pre-defined URL/adress combinations which unbound will load when it starts. And this can be used for spoofing/blocking certain domains (or sub-domains) e. g. point the adress for site foo.com to your local machine.<br>"
		           "qublc now allows to easily, but manually maintaining such a list of domains, which should not be contacted, and export it in a file format readable by unbound.<p>"
		           "Command line options:<br>"
		           "There are none. Call the program without any parameter and the GUI to maintain the URL list with the URLs to be blocked will show up.<br>"
		           "If any command line option(s) is given, a small info including the program version will be printed to standard out e. g. a terminal: qublc -h, qublc -v , it's all the same...<p>"
		           "<a href=""#Top"">back to top</a><p>"

		           "<hr>"
		           "<a name=""Usage""><b><u>How to use</u></b></a><p>"
		           "Start the program without any parameter in GUI mode.<br>"
		           "This program is only of any use, if you control a router which runs unbound as a resolver!<p>"
		           "Sites that set cookies often try to profile you, which is against privacy. However, there can be good reasons to share information e. g. when shopping online.<br>"
		           "There are other more intrusive methods to profile you, e. g. 1 pixel unseen pictures which will be loaded from external tracking servers and more evil technics qublc cannot protect you against!<br>"
		           "qublc only helps you to stop getting tracking cookies from sites you choose you want not beeing tracked by. Ironically these are the more honest sites, setting visible cookies, but they still want to track you!<p>"
		           "You visit sites that rely on advertisement? Super, allow advertisement, but block tracking cookies to secure your personal privacy! The advertisement can then not be 'personalized' - Yeap OK!<p>"
		           "Usually you will run this program on your desktop machine. Once a quarter or half a year you will start a browser session without blocking cookies (stop blocking cookies with unbound) and after surfing your usually suspects, you will see the cookies you have collected.<br>"
		           "You can now maintain the list of these sites in qublc. Add new entries and delete entries that do not show up anymore.<br>"
		           "Some of these advertisement sites are short living. Use the date function of qublc to memorize when you saw the site. If if does not show up after a long time, delete the site (top level domain + second and/or 3rd level domain) from the list.<br>"
		           "It will make unbound's life easier! :-)<p>"
		           "qublc has two (2) souls:<br>"
		           "1) is the management of the sites to be blocked. You can load and save the files with these list(s).<br>"
		           "2) export a conf file for unblock generated from the above mentioned site list. unbound will read this conf file on boot/start up and will act accordingly!<br>"
		           "Saving the unbound blacklist.conf file is an one way option! You cannot load an unbound blacklist.conf file!<p>"
		           "More important ! Delivering the generated unbound blacklist.conf file to your router/firewall is something you must manage separately!<br>"
		           "Assuming, that qublc is running on your desktop computer, you must find a way to :<br>"
		           " - store the generated unbound blacklist.conf file on your router/firewall (e. g. via USB stick) and - most importend !<br>"
		           " - configure the unbound service on your router/firewall to actually use it !<p>"
		           "<a href=""#Top"">back to top</a><p>"

		           "<hr>"
		           "<a name=""About cookies vs tracking cookies""><b><u>Cookies</u></b></a><p>"
		           "Cookies are not generally bad!<p>"
		           "BUT, yes but! They can and indeed are often used in a bad way.<br>"
		           "They can be and are used to profile you, tracking your behavior! There are other means, more complicated and not beeing prevented by qublc, to track you, 1 pixel graphics loaded from external servers beeing just one of these.<p>"
		           "However, cookies are usually required when doing business with sites, buying something.<br>"
		           "So as a rule of thumb, do not include sites you purchase from to an unbound blacklist.conf file.<p>"
		           "<a href=""#Top"">back to top</a><p>"

		           "<hr>"
		           "<a name=""Credits""><b><u>Credits</u></b></a><p>"
		           "qublc is based on Qt5.<p>"
		           "Icons where taken from the following themes or made by the listed persons:<br>"
		           "qublc.svg - made by me, Helge Kortendieck, a combination of the following free icons:<br>"
		           " - BillboardFrame.svg - freesvg.org - 2016 10 08 - Billboard image - PD CC0 1.0 Universal (CC0 1.0) Public Domain Dedication - original published by OpenClipart, ID 50115<br>"
		           " - Giggle.svg - freesvg.org - 2017 07 27 - Giggle emoji - PD CC0 1.0 Universal (CC0 1.0) Public Domain Dedication - original published by OpenClipart, ID 64122<br>"
		           " - Soda_Botle__Arvin61r58.svg - freesvg.org - 2015 09 14 - Vector illustration of small soda bottle - PD CC0 1.0 Universal (CC0 1.0) Public Domain Dedication - original published by OpenClipart, ID 32645<br>"
		           " - surveillance camera.svg - freesvg.org - 2015 01 06 - Vector clip art of outdoor CCTV camera - PD CC0 1.0 Universal (CC0 1.0) Public Domain Dedication - original published by OpenClipart, ID 20369<br>"
		           " - dialog-cancel-5.svg - open_icon_library V20091110 - oxygen - CC-BY-SA 3.0 or LGPL, actions/dialog-cancel-5.svg<br>"
		           "Programs internal action icons are taken from the open_icon_library version 10. Nov. 2009 .<br>"
		           "See http://openiconlibrary.sourceforge.net/ licenses see: LICENSES_full_documentation_gpl.txt .<p>"
		           " about.svg - open_icon_library V20091110 - gnome - GPLv2, actions/help-about.svg<br>"
		           " exit.svg - open_icon_library V20091110 - gnome-Colors - GPLv2, actions/application-exit-3.svg<br>"
		           " export.svg - open_icon_library V20091110 - oxygen - CC-BY-SA 3.0 or LGPL, actions/document-export-4.svg - arrow colored and changed by me, Helge Kortendieck, 2020 03<br>"
		           " help.svg - open_icon_library V20091110 - gnome - GPLv2, apps/help-browser.svg<br>"
		           " minus.svg - freesvg.org - 20191118 - remove - PD CC0 1.0 Universal (CC0 1.0) Public Domain Dedication - original published by OpenClipart<br>"
		           " new.svg - freesvg.org - 20170402 - Add document - PD CC0 1.0 Universal (CC0 1.0) Public Domain Dedication - original published by OpenClipart<br>"
		           " open.svg - open_icon_library V20091110 - tango - PD, actions/document-open-5.svg<br>"
		           " plus.svg - freesvg.org	- 20171119 - Green plus image - PD CC0 1.0 Universal (CC0 1.0) Public Domain Dedication - original published by OpenClipart<br>"
		           " save.svg - open_icon_library V20091110 - gnome - GPLv2, actions/document-save-2.svg<br>"
		           " save-as.svg - open_icon_library V20091110 - oxygen - CC-BY-SA 3.0 or LGPL, actions/document-save-as-5.svg<br>"
		           "Program and Documentation Copyright 2019-2020 Helge Kortendieck, alan@kasmithee.de .<p>"
		           "qublc is released under the MIT license, except of it's icons!<br>"
		           "Please note, that the icons comming with qublc are _NOT_ under the MIT license! See above...<p>"
		           "<a href=""#Top"">back to top</a><p>"
		           "</body></html>");
	}
}


//#include "abouthelp.moc"
